@@ -38,18 +38,19 @@
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
 
+#include <libhal-gdevice.h>
+#include <libhal-gmanager.h>
+
 #include "gpm-common.h"
 #include "gpm-debug.h"
-#include "gpm-hal.h"
 #include "gpm-ac-adapter.h"
 
 #define GPM_AC_ADAPTER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_AC_ADAPTER, GpmAcAdapterPrivate))
 
 struct GpmAcAdapterPrivate
 {
-	gchar			*udi;
 	gboolean		 has_hardware;
-	GpmHal			*hal;
+	HalGDevice		*hal_device;
 };
 
 enum {
@@ -57,7 +58,8 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint	     signals [LAST_SIGNAL] = { 0, };
+static guint signals [LAST_SIGNAL] = { 0, };
+static gpointer gpm_ac_adapter_object = NULL;
 
 G_DEFINE_TYPE (GpmAcAdapter, gpm_ac_adapter, G_TYPE_OBJECT)
 
@@ -68,8 +70,7 @@ G_DEFINE_TYPE (GpmAcAdapter, gpm_ac_adapter, G_TYPE_OBJECT)
  * Gets the current state of the AC adapter
  **/
 gboolean
-gpm_ac_adapter_get_state (GpmAcAdapter *ac_adapter,
-		          GpmAcAdapterState *state)
+gpm_ac_adapter_is_present (GpmAcAdapter *ac_adapter)
 {
 	gboolean is_on_ac;
 	GError *error;
@@ -79,24 +80,21 @@ gpm_ac_adapter_get_state (GpmAcAdapter *ac_adapter,
 
 	/* bodge for now, PC's are considered on AC power */
 	if (ac_adapter->priv->has_hardware == FALSE) {
-		*state = GPM_AC_ADAPTER_PRESENT;
 		return TRUE;
 	}
 
 	error = NULL;
-	gpm_hal_device_get_bool (ac_adapter->priv->hal, ac_adapter->priv->udi,
-				 "ac_adapter.present", &is_on_ac, &error);
+	hal_gdevice_get_bool (ac_adapter->priv->hal_device,
+			      "ac_adapter.present", &is_on_ac, &error);
 	if (error != NULL) {
 		gpm_warning ("could not read ac_adapter.present");
 		g_error_free (error);
 	}
 
 	if (is_on_ac == TRUE) {
-		*state = GPM_AC_ADAPTER_PRESENT;
-	} else {
-		*state = GPM_AC_ADAPTER_MISSING;
+		return TRUE;
 	}
-	return TRUE;
+	return FALSE;
 }
 
 /**
@@ -111,19 +109,17 @@ gpm_ac_adapter_get_state (GpmAcAdapter *ac_adapter,
  * changed, and we have we have subscribed to changes for that device.
  */
 static void
-hal_device_property_modified_cb (GpmHal       *hal,
-				 const gchar  *udi,
+hal_device_property_modified_cb (HalGDevice   *hal_device,
 				 const gchar  *key,
 				 gboolean      is_added,
 				 gboolean      is_removed,
 				 gboolean      finally,
 				 GpmAcAdapter *ac_adapter)
 {
-	GpmAcAdapterState state;
-
+	gboolean on_ac;
 	if (strcmp (key, "ac_adapter.present") == 0) {
-		gpm_ac_adapter_get_state (ac_adapter, &state);
-		g_signal_emit (ac_adapter, signals [AC_ADAPTER_CHANGED], 0, state);
+		on_ac = gpm_ac_adapter_is_present (ac_adapter);
+		g_signal_emit (ac_adapter, signals [AC_ADAPTER_CHANGED], 0, on_ac);
 		return;
 	}
 }
@@ -154,11 +150,10 @@ gpm_ac_adapter_finalize (GObject *object)
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (GPM_IS_AC_ADAPTER (object));
 	ac_adapter = GPM_AC_ADAPTER (object);
-
-	g_free (ac_adapter->priv->udi);
-	g_object_unref (ac_adapter->priv->hal);
-
 	g_return_if_fail (ac_adapter->priv != NULL);
+
+	g_object_unref (ac_adapter->priv->hal_device);
+
 	G_OBJECT_CLASS (gpm_ac_adapter_parent_class)->finalize (object);
 }
 
@@ -201,13 +196,15 @@ gpm_ac_adapter_init (GpmAcAdapter *ac_adapter)
 	gchar **device_names;
 	gboolean ret;
 	GError *error;
+	HalGManager *hal_manager;
 
 	ac_adapter->priv = GPM_AC_ADAPTER_GET_PRIVATE (ac_adapter);
-	ac_adapter->priv->hal = gpm_hal_new ();
+	ac_adapter->priv->hal_device = hal_gdevice_new ();
+	hal_manager = hal_gmanager_new ();
 
 	/* save udi of lcd adapter */
 	error = NULL;
-	ret = gpm_hal_device_find_capability (ac_adapter->priv->hal, "ac_adapter", &device_names, &error);
+	ret = hal_gmanager_find_capability (hal_manager, "ac_adapter", &device_names, &error);
 	if (ret == FALSE) {
 		gpm_warning ("Couldn't obtain list of AC adapters: %s", error->message);
 		g_error_free (error);
@@ -217,23 +214,22 @@ gpm_ac_adapter_init (GpmAcAdapter *ac_adapter)
 		/* we track this by hand as machines that have no ac_adapter object must
 		 * return that they are on ac power */
 		ac_adapter->priv->has_hardware = TRUE;
+		gpm_debug ("using %s", device_names[0]);
 
 		/* We only want first ac_adapter object (should only be one) */
-		ac_adapter->priv->udi = g_strdup (device_names[0]);
-
-		/* watch this device */
-		gpm_hal_device_watch_propery_modified (ac_adapter->priv->hal, ac_adapter->priv->udi, FALSE);
+		hal_gdevice_set_udi (ac_adapter->priv->hal_device, device_names[0]);
+		hal_gdevice_watch_property_modified (ac_adapter->priv->hal_device);
 
 		/* we want state changes */
-		g_signal_connect (ac_adapter->priv->hal, "property-modified",
-				  G_CALLBACK (hal_device_property_modified_cb), ac_adapter);		
+		g_signal_connect (ac_adapter->priv->hal_device, "property-modified",
+				  G_CALLBACK (hal_device_property_modified_cb), ac_adapter);
 	} else {
 		/* no ac-adapter class support */
 		ac_adapter->priv->has_hardware = FALSE;
-		ac_adapter->priv->udi = NULL;
 		gpm_debug ("No devices of capability ac_adapter");
 	}
-	gpm_hal_free_capability (ac_adapter->priv->hal, device_names);
+	hal_gmanager_free_capability (device_names);
+	g_object_unref (hal_manager);
 }
 
 /**
@@ -243,11 +239,12 @@ gpm_ac_adapter_init (GpmAcAdapter *ac_adapter)
 GpmAcAdapter *
 gpm_ac_adapter_new (void)
 {
-	static GpmAcAdapter *ac_adapter = NULL;
-	if (ac_adapter != NULL) {
-		g_object_ref (ac_adapter);
+	if (gpm_ac_adapter_object != NULL) {
+		g_object_ref (gpm_ac_adapter_object);
 	} else {
-		ac_adapter = g_object_new (GPM_TYPE_AC_ADAPTER, NULL);
+		gpm_ac_adapter_object = g_object_new (GPM_TYPE_AC_ADAPTER, NULL);
+		g_object_add_weak_pointer (gpm_ac_adapter_object, &gpm_ac_adapter_object);
 	}
-	return ac_adapter;
+	return GPM_AC_ADAPTER (gpm_ac_adapter_object);
 }
+
