@@ -42,32 +42,23 @@
 #include <dbus/dbus-glib-lowlevel.h>
 #include <gnome-keyring.h>
 
+#include <libhal-gpower.h>
+
 #include "gpm-conf.h"
 #include "gpm-screensaver.h"
 #include "gpm-common.h"
 #include "gpm-debug.h"
-#include "gpm-hal.h"
 #include "gpm-control.h"
 #include "gpm-polkit.h"
-#include "gpm-dbus-monitor.h"
 #include "gpm-networkmanager.h"
 
 #define GPM_CONTROL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_CONTROL, GpmControlPrivate))
 
-typedef struct
-{
-	gchar			*application;
-	gchar			*connection;
-	guint32			 cookie;
-} GpmControlData;
-
 struct GpmControlPrivate
 {
 	GpmConf			*conf;
-	GpmHal			*hal;
+	HalGPower		*hal_power;
 	GpmPolkit		*polkit;
-	GSList			*list;
-	GpmDbusMonitor		*dbus_monitor;
 	time_t			 last_resume_event;
 	guint			 suppress_policy_timeout;
 };
@@ -80,7 +71,8 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint	     signals [LAST_SIGNAL] = { 0, };
+static guint signals [LAST_SIGNAL] = { 0, };
+static gpointer gpm_control_object = NULL;
 
 G_DEFINE_TYPE (GpmControl, gpm_control, G_TYPE_OBJECT)
 
@@ -112,10 +104,8 @@ gpm_control_error_quark (void)
  * Return value: TRUE if we can perform the action.
  **/
 gboolean
-gpm_control_is_policy_timout_valid (GpmControl  *control,
-				    const gchar *action)
+gpm_control_is_policy_timout_valid (GpmControl *control)
 {
-	gchar *message;
 #ifdef HAVE_CHECK_FG
 	gchar *argv[] = { "check-foreground-console", NULL };
 	int retcode;
@@ -123,9 +113,7 @@ gpm_control_is_policy_timout_valid (GpmControl  *control,
 
 	if ((time (NULL) - control->priv->last_resume_event) <=
 	    control->priv->suppress_policy_timeout) {
-		message = g_strdup_printf ("Skipping suppressed %s", action);
-		gpm_debug (message);
-		g_free (message);
+		gpm_debug ("Skipping suppressed action");
 		return FALSE;
 	}
 
@@ -157,222 +145,6 @@ gpm_control_reset_event_time (GpmControl *control)
 	control->priv->last_resume_event = time (NULL);
 }
 
-/**
- * gpm_control_cookie_compare_func
- * @a: Pointer to the data to test
- * @b: Pointer to a cookie to compare
- *
- * A GCompareFunc for comparing a cookie to a list.
- *
- * Return value: 0 if cookie matches
- **/
-static gint
-gpm_control_cookie_compare_func (gconstpointer a, gconstpointer b)
-{
-	GpmControlData *data;
-	guint32		cookie;
-	data = (GpmControlData*) a;
-	cookie = *((guint32*) b);
-	if (cookie == data->cookie)
-		return 0;
-	return 1;
-}
-
-/**
- * gpm_control_find_cookie:
- * @control: This control instance
- * @cookie: The cookie we are looking for
- *
- * Finds the data in the cookie list.
- *
- * Return value: The cookie data, or NULL if not found
- **/
-static GpmControlData *
-gpm_control_find_cookie (GpmControl *control, guint32 cookie)
-{
-	GpmControlData *data;
-	GSList	       *ret;
-	ret = g_slist_find_custom (control->priv->list, &cookie,
-				   gpm_control_cookie_compare_func);
-	if (! ret) {
-		return NULL;
-	}
-	data = (GpmControlData *) ret->data;
-	return data;
-}
-
-/**
- * gpm_control_generate_cookie:
- * @control: This control instance
- *
- * Returns a random cookie not already allocated.
- *
- * Return value: a new random cookie.
- **/
-static guint32
-gpm_control_generate_cookie (GpmControl *control)
-{
-	guint32		cookie;
-
-	/* Iterate until we have a unique cookie */
-	do {
-		cookie = (guint32) g_random_int_range (1, G_MAXINT32);
-	} while (gpm_control_find_cookie (control, cookie));
-	return cookie;
-}
-
-/**
- * gpm_control_request_cookie:
- * @connection: Connection name, e.g. ":0.13"
- * @application:	Application name, e.g. "Nautilus"
- * @reason: Reason for controling, e.g. "Copying files"
- *
- * Allocates a random cookie used to identify the connection, as multiple
- * control requests can come from one caller sharing a dbus connection.
- * We need to refcount internally, and data is saved in the GpmControlData
- * struct.
- *
- * Return value: a new random cookie.
- **/
-void
-gpm_control_register (GpmControl  *control,
-		      const gchar *application,
-		      DBusGMethodInvocation *context,
-		      GError	**error)
-{
-	const gchar *connection;
-	GpmControlData *data;
-
-	/* as we are async, we can get the sender */
-	connection = dbus_g_method_get_sender (context);
-
-	/* handle where the application does not add required data */
-	if (connection == NULL ||
-	    application == NULL) {
-		gpm_warning ("Recieved Actions, but application "
-			     "did not set the parameters correctly");
-		dbus_g_method_return (context, -1);
-		return;
-	}
-
-	/* seems okay, add to list */
-	data = g_new (GpmControlData, 1);
-	data->cookie = gpm_control_generate_cookie (control);
-	data->application = g_strdup (application);
-	data->connection = g_strdup (connection);
-
-	control->priv->list = g_slist_append (control->priv->list,
-					      (gpointer) data);
-
-	gpm_debug ("Recieved Actions from '%s' (%s) saving as #%i",
-		   data->application, data->connection, data->cookie);
-
-	dbus_g_method_return (context, data->cookie);
-}
-
-/* free one element in GpmControlData struct */
-static void
-gpm_control_free_data_object (GpmControlData *data)
-{
-	g_free (data->application);
-	g_free (data->connection);
-	g_free (data);
-}
-
-/**
- * gpm_control_clear_cookie:
- * @application:	Application name
- * @cookie: The cookie that we used to register
- *
- * Removes a cookie and associated data from the GpmControlData struct.
- **/
-gboolean
-gpm_control_un_register (GpmControl  *control,
-		         guint32      cookie,
-		         GError     **error)
-{
-	GpmControlData *data;
-
-	/* Only remove the correct cookie */
-	data = gpm_control_find_cookie (control, cookie);
-	if (data == NULL) {
-		gpm_warning ("Cannot find registered program for #%i, so "
-			     "cannot do UnActions", cookie);
-		return FALSE;
-	}
-	gpm_debug ("UnActions okay #%i", cookie);
-	gpm_control_free_data_object (data);
-	control->priv->list = g_slist_remove (control->priv->list,
-					      (gconstpointer) data);
-	return TRUE;
-}
-
-/**
- * gpm_control_get_requests:
- *
- * Gets a list of controls.
- **/
-gboolean
-gpm_control_policy (GpmControl *control,
-		    guint32	cookie,
-		    gboolean	allowed,
-		    GError    **error)
-{
-	gpm_warning ("Not implimented");
-	return FALSE;
-}
-
-/**
- * gpm_control_remove_dbus:
- * @connection: Connection name
- * @application:	Application name
- * @cookie: The cookie that we used to register
- *
- * Checks to see if the dbus closed session is registered, in which case
- * unregister it.
- **/
-static void
-gpm_control_remove_dbus (GpmControl  *control,
-			 const gchar *connection)
-{
-	int a;
-	GpmControlData *data;
-	/* Remove *any* connections that match the connection */
-	for (a=0; a<g_slist_length (control->priv->list); a++) {
-		data = (GpmControlData *) g_slist_nth_data (control->priv->list, a);
-		if (strcmp (data->connection, connection) == 0) {
-			gpm_debug ("Auto-revoked idle control on '%s'.",
-				   data->application);
-			gpm_control_free_data_object (data);
-			control->priv->list = g_slist_remove (control->priv->list,
-							      (gconstpointer) data);
-		}
-	}
-	return;
-}
-
-/**
- * dbus_noc_session_cb:
- * @power: The power class instance
- * @name: The DBUS name, e.g. hal.freedesktop.org
- * @prev: The previous name, e.g. :0.13
- * @new: The new name, e.g. :0.14
- * @control: This control class instance
- *
- * The noc session DBUS callback.
- **/
-static void
-dbus_noc_session_cb (GpmDbusMonitor *dbus_monitor,
-		     const gchar    *name,
-		     const gchar    *prev,
-		     const gchar    *new,
-		     GpmControl	    *control)
-{
-	if (strlen (new) == 0) {
-		gpm_control_remove_dbus (control, name);
-	}
-}
-
 /**
  * gpm_control_allowed_suspend:
  * @control: This class instance
@@ -393,7 +165,7 @@ gpm_control_allowed_suspend (GpmControl *control,
 
 	*can = FALSE;
 	gpm_conf_get_bool (control->priv->conf, GPM_CONF_CAN_SUSPEND, &conf_ok);
-	hal_ok = gpm_hal_can_suspend (control->priv->hal);
+	hal_ok = hal_gpower_can_suspend (control->priv->hal_power);
 	if (control->priv->polkit) {
 		polkit_ok = gpm_polkit_is_user_privileged (control->priv->polkit, "hal-power-suspend");
 	}
@@ -424,7 +196,7 @@ gpm_control_allowed_hibernate (GpmControl *control,
 
 	*can = FALSE;
 	gpm_conf_get_bool (control->priv->conf, GPM_CONF_CAN_HIBERNATE, &conf_ok);
-	hal_ok = gpm_hal_can_hibernate (control->priv->hal);
+	hal_ok = hal_gpower_can_hibernate (control->priv->hal_power);
 	if (control->priv->polkit) {
 		polkit_ok = gpm_polkit_is_user_privileged (control->priv->polkit, "hal-power-hibernate");
 	}
@@ -513,7 +285,7 @@ gpm_control_shutdown (GpmControl *control,
 					   GNOME_SAVE_GLOBAL,
 					   FALSE, GNOME_INTERACT_NONE, FALSE,  TRUE);
 	}
-	gpm_hal_shutdown (control->priv->hal);
+	hal_gpower_shutdown (control->priv->hal_power);
 	ret = TRUE;
 
 	return ret;
@@ -552,7 +324,7 @@ gpm_control_reboot (GpmControl *control,
 					   FALSE, GNOME_INTERACT_NONE, FALSE,  TRUE);
 	}
 
-	gpm_hal_reboot (control->priv->hal);
+	hal_gpower_reboot (control->priv->hal_power);
 	ret = TRUE;
 
 	return ret;
@@ -597,11 +369,10 @@ gpm_control_suspend (GpmControl *control,
 	gboolean ret;
 	gboolean do_lock;
 	gboolean nm_sleep;
-#if HAVE_GNOME_KEYRING
+	gboolean lock_gnome_keyring;
 	GnomeKeyringResult keyres;
-#endif
 	GpmScreensaver *screensaver;
-	
+
 	screensaver = gpm_screensaver_new ();
 
 	gpm_control_allowed_suspend (control, &allowed, error);
@@ -615,13 +386,14 @@ gpm_control_suspend (GpmControl *control,
 		return FALSE;
 	}
 
-#if HAVE_GNOME_KEYRING
-	/* we should lock keyrings when sleeping #375681 */
-	keyres = gnome_keyring_lock_all_sync ();
-	if (keyres != GNOME_KEYRING_RESULT_OK) {
-		gpm_debug ("could not lock keyring");
+	/* we should perhaps lock keyrings when sleeping #375681 */
+	gpm_conf_get_bool (control->priv->conf, GPM_CONF_LOCK_GNOME_KEYRING, &lock_gnome_keyring);
+	if (lock_gnome_keyring == TRUE) {
+		keyres = gnome_keyring_lock_all_sync ();
+		if (keyres != GNOME_KEYRING_RESULT_OK) {
+			gpm_warning ("could not lock keyring");
+		}
 	}
-#endif
 
 	do_lock = gpm_control_get_lock_policy (control, GPM_CONF_LOCK_ON_SUSPEND);
 	if (do_lock == TRUE) {
@@ -636,7 +408,7 @@ gpm_control_suspend (GpmControl *control,
 	/* Do the suspend */
 	gpm_debug ("emitting sleep");
 	g_signal_emit (control, signals [SLEEP], 0, GPM_CONTROL_ACTION_SUSPEND);
-	ret = gpm_hal_suspend (control->priv->hal, 0);
+	ret = hal_gpower_suspend (control->priv->hal_power, 0);
 	gpm_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_SUSPEND);
 
@@ -668,12 +440,11 @@ gpm_control_hibernate (GpmControl *control,
 	gboolean allowed;
 	gboolean ret;
 	gboolean do_lock;
-        gboolean nm_sleep;
-#if HAVE_GNOME_KEYRING
+	gboolean nm_sleep;
+	gboolean lock_gnome_keyring;
 	GnomeKeyringResult keyres;
-#endif
 	GpmScreensaver *screensaver;
-	
+
 	screensaver = gpm_screensaver_new ();
 
 	gpm_control_allowed_hibernate (control, &allowed, error);
@@ -688,13 +459,14 @@ gpm_control_hibernate (GpmControl *control,
 		return FALSE;
 	}
 
-#if HAVE_GNOME_KEYRING
-	/* we should lock keyrings when sleeping #375681 */
-	keyres = gnome_keyring_lock_all_sync ();
-	if (keyres != GNOME_KEYRING_RESULT_OK) {
-		gpm_debug ("could not lock keyring");
+	/* we should perhaps lock keyrings when sleeping #375681 */
+	gpm_conf_get_bool (control->priv->conf, GPM_CONF_LOCK_GNOME_KEYRING, &lock_gnome_keyring);
+	if (lock_gnome_keyring == TRUE) {
+		keyres = gnome_keyring_lock_all_sync ();
+		if (keyres != GNOME_KEYRING_RESULT_OK) {
+			gpm_warning ("could not lock keyring");
+		}
 	}
-#endif
 
 	do_lock = gpm_control_get_lock_policy (control, GPM_CONF_LOCK_ON_HIBERNATE);
 	if (do_lock == TRUE) {
@@ -708,7 +480,7 @@ gpm_control_hibernate (GpmControl *control,
 
 	gpm_debug ("emitting sleep");
 	g_signal_emit (control, signals [SLEEP], 0, GPM_CONTROL_ACTION_HIBERNATE);
-	ret = gpm_hal_hibernate (control->priv->hal);
+	ret = hal_gpower_hibernate (control->priv->hal_power);
 	gpm_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_HIBERNATE);
 
@@ -738,8 +510,8 @@ gpm_control_hibernate (GpmControl *control,
  **/
 static GObject *
 gpm_control_constructor (GType		  type,
-			      guint		  n_construct_properties,
-			      GObjectConstructParam *construct_properties)
+			 guint		  n_construct_properties,
+			 GObjectConstructParam *construct_properties)
 {
 	GpmControl      *control;
 	GpmControlClass *klass;
@@ -756,32 +528,17 @@ static void
 gpm_control_finalize (GObject *object)
 {
 	GpmControl *control;
-	guint a;
-	GpmControlData *data;
 
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (GPM_IS_CONTROL (object));
 	control = GPM_CONTROL (object);
 
-	if (control->priv->conf) {
-		g_object_unref (control->priv->conf);
-	}
-	if (control->priv->hal) {
-		g_object_unref (control->priv->hal);
-	}
+	g_object_unref (control->priv->conf);
+	g_object_unref (control->priv->hal_power);
 	if (control->priv->polkit) {
 		g_object_unref (control->priv->polkit);
 	}
 
-	/* remove items in list and free */
-	for (a=0; a<g_slist_length (control->priv->list); a++) {
-		data = (GpmControlData *) g_slist_nth_data (control->priv->list, a);
-		gpm_control_free_data_object (data);
-	}
-	g_slist_free (control->priv->list);
-
-	g_object_unref (control->priv->dbus_monitor);
-
 	g_return_if_fail (control->priv != NULL);
 	G_OBJECT_CLASS (gpm_control_parent_class)->finalize (object);
 }
@@ -851,10 +608,7 @@ gpm_control_init (GpmControl *control)
 
 	/* this will be NULL if we don't compile in support */
 	control->priv->polkit = gpm_polkit_new ();
-	control->priv->hal = gpm_hal_new ();
-	control->priv->dbus_monitor = gpm_dbus_monitor_new ();
-	g_signal_connect (control->priv->dbus_monitor, "noc-session",
-			  G_CALLBACK (dbus_noc_session_cb), control);
+	control->priv->hal_power = hal_gpower_new ();
 
 	control->priv->conf = gpm_conf_new ();
 	gpm_conf_get_uint (control->priv->conf, GPM_CONF_POLICY_TIMEOUT,
@@ -873,13 +627,12 @@ gpm_control_init (GpmControl *control)
 GpmControl *
 gpm_control_new (void)
 {
-	static GpmControl *control = NULL;
-
-	if (control != NULL) {
-		g_object_ref (control);
-		return control;
+	if (gpm_control_object != NULL) {
+		g_object_ref (gpm_control_object);
+	} else {
+		gpm_control_object = g_object_new (GPM_TYPE_CONTROL, NULL);
+		g_object_add_weak_pointer (gpm_control_object, &gpm_control_object);
 	}
-
-	control = g_object_new (GPM_TYPE_CONTROL, NULL);
-	return control;
+	return GPM_CONTROL (gpm_control_object);
 }
+
