@@ -40,7 +40,8 @@
 #include "gpm-cell.h"
 #include "gpm-debug.h"
 #include "gpm-stock-icons.h"
-#include "gpm-warning.h"
+#include "gpm-warnings.h"
+#include "gpm-prefs-server.h"
 
 static void     gpm_engine_class_init (GpmEngineClass *klass);
 static void     gpm_engine_init       (GpmEngine      *engine);
@@ -54,7 +55,7 @@ static void     gpm_engine_finalize   (GObject	  *object);
 struct GpmEnginePrivate
 {
 	GpmConf			*conf;
-	GpmWarning		*warning;
+	GpmWarnings		*warnings;
 	GpmIconPolicy		 icon_policy;
 	GpmProfile		*profile;
 	GpmControl		*control;
@@ -296,9 +297,14 @@ gpm_engine_get_summary (GpmEngine *engine)
 
 	/* if we have limited accuracy, add this to the tooltip */
 	unit = gpm_cell_array_get_unit (collection->primary);
-	accuracy = gpm_profile_get_accuracy (engine->priv->profile, unit->percentage);
-	if (accuracy < GPM_ENGINE_WARN_ACCURACY && unit->is_present == TRUE) {
-		tooltip = g_string_append (tooltip, _("Battery charge profile is estimated\n"));
+	accuracy = gpm_profile_get_accuracy_average (engine->priv->profile,
+						     unit->is_discharging);
+	if (accuracy < GPM_PROFILE_GOOD_TRUST && unit->is_present == TRUE) {
+		if (unit->is_discharging) {
+			tooltip = g_string_append (tooltip, _("Battery discharge time is estimated\n"));
+		} else {
+			tooltip = g_string_append (tooltip, _("Battery charge time is estimated\n"));
+		}
 	}
 
 	part = gpm_cell_array_get_description (collection->ups);
@@ -343,7 +349,7 @@ gpm_engine_get_icon (GpmEngine *engine)
 	GpmCellUnit *unit_mouse;
 	GpmCellUnit *unit_keyboard;
 	GpmEngineCollection *collection;
-	GpmWarningState state;
+	GpmWarningsState state;
 
 	/* grab a reference to the collection */
 	collection = &engine->priv->collection;
@@ -364,20 +370,20 @@ gpm_engine_get_icon (GpmEngine *engine)
 
 	/* we try CRITICAL: PRIMARY, UPS, MOUSE, KEYBOARD */
 	gpm_debug ("Trying CRITICAL icon: primary, ups, mouse, keyboard");
-	state = gpm_warning_get_state (engine->priv->warning, unit_primary);
-	if (unit_primary->is_present == TRUE && state == GPM_WARNING_CRITICAL) {
+	state = gpm_warnings_get_state (engine->priv->warnings, unit_primary);
+	if (unit_primary->is_present == TRUE && state == GPM_WARNINGS_CRITICAL) {
 		return gpm_cell_array_get_icon (collection->primary);
 	}
-	state = gpm_warning_get_state (engine->priv->warning, unit_ups); 
-	if (unit_ups->is_present == TRUE && state == GPM_WARNING_CRITICAL) {
+	state = gpm_warnings_get_state (engine->priv->warnings, unit_ups); 
+	if (unit_ups->is_present == TRUE && state == GPM_WARNINGS_CRITICAL) {
 		return gpm_cell_array_get_icon (collection->ups);
 	}
-	state = gpm_warning_get_state (engine->priv->warning, unit_mouse);
-	if (unit_mouse->is_present == TRUE && state == GPM_WARNING_CRITICAL) {
+	state = gpm_warnings_get_state (engine->priv->warnings, unit_mouse);
+	if (unit_mouse->is_present == TRUE && state == GPM_WARNINGS_CRITICAL) {
 		return gpm_cell_array_get_icon (collection->mouse);
 	}
-	state = gpm_warning_get_state (engine->priv->warning, unit_keyboard);
-	if (unit_keyboard->is_present == TRUE && state == GPM_WARNING_CRITICAL) {
+	state = gpm_warnings_get_state (engine->priv->warnings, unit_keyboard);
+	if (unit_keyboard->is_present == TRUE && state == GPM_WARNINGS_CRITICAL) {
 		return gpm_cell_array_get_icon (collection->keyboard);
 	}
 
@@ -826,10 +832,10 @@ conf_key_changed_cb (GpmConf     *conf,
 		     GpmEngine   *engine)
 {
 	gchar *icon_policy;
-	if (strcmp (key, GPM_CONF_ICON_POLICY) == 0) {
+	if (strcmp (key, GPM_CONF_UI_ICON_POLICY) == 0) {
 
 		/* do we want to display the icon in the tray */
-		gpm_conf_get_string (conf, GPM_CONF_ICON_POLICY, &icon_policy);
+		gpm_conf_get_string (conf, GPM_CONF_UI_ICON_POLICY, &icon_policy);
 		engine->priv->icon_policy = gpm_tray_icon_mode_from_string (icon_policy);
 		g_free (icon_policy);
 
@@ -854,7 +860,7 @@ gpm_engine_init (GpmEngine *engine)
 	g_signal_connect (engine->priv->conf, "value-changed",
 			  G_CALLBACK (conf_key_changed_cb), engine);
 
-	engine->priv->warning = gpm_warning_new ();
+	engine->priv->warnings = gpm_warnings_new ();
 	engine->priv->profile = gpm_profile_new ();
 
 	engine->priv->previous_icon = NULL;
@@ -863,7 +869,7 @@ gpm_engine_init (GpmEngine *engine)
 	engine->priv->during_coldplug = TRUE;
 
 	/* do we want to display the icon in the tray */
-	gpm_conf_get_string (engine->priv->conf, GPM_CONF_ICON_POLICY, &icon_policy);
+	gpm_conf_get_string (engine->priv->conf, GPM_CONF_UI_ICON_POLICY, &icon_policy);
 	engine->priv->icon_policy = gpm_tray_icon_mode_from_string (icon_policy);
 	g_free (icon_policy);
 
@@ -962,6 +968,7 @@ gboolean
 gpm_engine_start (GpmEngine *engine)
 {
 	GpmEngineCollection *collection;
+	GpmPrefsServer *prefs_server;
 
 	g_return_val_if_fail (engine != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_ENGINE (engine), FALSE);
@@ -974,6 +981,16 @@ gpm_engine_start (GpmEngine *engine)
 	gpm_cell_array_set_type (collection->keyboard, GPM_CELL_UNIT_KIND_KEYBOARD);
 	gpm_cell_array_set_type (collection->pda, GPM_CELL_UNIT_KIND_PDA);
 
+	/* only show the battery prefs section if we have batteries */
+	prefs_server = gpm_prefs_server_new ();
+	if (gpm_cell_array_get_num_cells (collection->primary) > 0) {
+		gpm_prefs_server_set_capability (prefs_server, GPM_PREFS_SERVER_BATTERY);
+	}
+	if (gpm_cell_array_get_num_cells (collection->ups) > 0) {
+		gpm_prefs_server_set_capability (prefs_server, GPM_PREFS_SERVER_UPS);
+	}
+	g_object_unref (prefs_server);
+
 	/* we're done */
 	engine->priv->during_coldplug = FALSE;
 
@@ -1011,7 +1028,7 @@ gpm_engine_finalize (GObject *object)
 
 	g_object_unref (engine->priv->hal_manager);
 	g_object_unref (engine->priv->profile);
-	g_object_unref (engine->priv->warning);
+	g_object_unref (engine->priv->warnings);
 	g_object_unref (engine->priv->ac_adapter);
 	g_object_unref (engine->priv->control);
 }
