@@ -52,6 +52,9 @@ static void     gpm_info_finalize   (GObject      *object);
 #define GPM_INFO_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_INFO, GpmInfoPrivate))
 
 #define GPM_INFO_DATA_POLL		5	/* seconds */
+#define GPM_COLOUR_CHARGING			GPM_COLOUR_BLUE
+#define GPM_COLOUR_DISCHARGING			GPM_COLOUR_DARK_RED
+#define GPM_COLOUR_CHARGED			GPM_COLOUR_GREEN
 
 #define GPM_DBUS_STRUCT_INT_INT (dbus_g_type_get_struct ("GValueArray", \
 	G_TYPE_INT, G_TYPE_INT, G_TYPE_INVALID))
@@ -198,6 +201,10 @@ gpm_statistics_add_events_typical (GPtrArray *array)
 				       GPM_COLOUR_DARK_BLUE,
 				       GPM_GRAPH_WIDGET_SHAPE_CIRCLE,
 				       _("On battery"));
+	gpm_statistics_add_event_type (array, GPM_EVENT_SESSION_POWERSAVE,
+				       GPM_COLOUR_WHITE,
+				       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
+				       _("Session powersave"));
 	gpm_statistics_add_event_type (array, GPM_EVENT_SESSION_IDLE,
 				       GPM_COLOUR_YELLOW,
 				       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
@@ -209,15 +216,15 @@ gpm_statistics_add_events_typical (GPtrArray *array)
 	gpm_statistics_add_event_type (array, GPM_EVENT_SUSPEND,
 				       GPM_COLOUR_RED,
 				       GPM_GRAPH_WIDGET_SHAPE_DIAMOND,
-				       _("Suspend"));
+				       Q_("label shown on graph|Suspend"));
 	gpm_statistics_add_event_type (array, GPM_EVENT_RESUME,
 				       GPM_COLOUR_DARK_RED,
 				       GPM_GRAPH_WIDGET_SHAPE_DIAMOND,
-				       _("Resume"));
+				       Q_("label shown on graph|Resume"));
 	gpm_statistics_add_event_type (array, GPM_EVENT_HIBERNATE,
 				       GPM_COLOUR_MAGENTA,
 				       GPM_GRAPH_WIDGET_SHAPE_DIAMOND,
-				       _("Hibernate"));
+				       Q_("label shown on graph|Hibernate"));
 	gpm_statistics_add_event_type (array, GPM_EVENT_LID_CLOSED,
 				       GPM_COLOUR_GREEN,
 				       GPM_GRAPH_WIDGET_SHAPE_TRIANGLE,
@@ -281,7 +288,7 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_x = g_strdup ("time");
 		*axis_type_y = g_strdup ("power");
 		*axis_desc_x = g_strdup (_("Time since startup"));
-		*axis_desc_y = g_strdup (_("Power (mWh)"));
+		*axis_desc_y = g_strdup (_("Power"));
 		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Power"));
 		gpm_statistics_add_events_typical (*key_event);
 		return TRUE;
@@ -714,9 +721,10 @@ idle_changed_cb (GpmIdle     *idle,
 {
 	if (mode == GPM_IDLE_MODE_NORMAL) {
 		gpm_info_event_log (info, GPM_EVENT_SESSION_ACTIVE, _("idle mode ended"));
-
 	} else if (mode == GPM_IDLE_MODE_SESSION) {
 		gpm_info_event_log (info, GPM_EVENT_SESSION_IDLE, _("idle mode started"));
+	} else if (mode == GPM_IDLE_MODE_POWERSAVE) {
+		gpm_info_event_log (info, GPM_EVENT_SESSION_POWERSAVE, _("powersave mode started"));
 	}
 }
 
