@@ -2,7 +2,7 @@
  *
  * Copyright (C) 2005 Jaap Haitsma <jaap@haitsma.org>
  * Copyright (C) 2005 William Jon McCann <mccann@jhu.edu>
- * Copyright (C) 2005-2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -116,12 +116,14 @@ main (int argc, char **argv)
 		{ NULL}
 	};
 
-	context = g_option_context_new (_("GNOME Power Preferences"));
+	context = g_option_context_new (N_("GNOME Power Preferences"));
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
+	g_option_context_set_translation_domain(context, GETTEXT_PACKAGE);
+
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 
 #if HAVE_GTKUNIQUE
