@@ -29,7 +29,6 @@
 void
 gpm_st_array_float (GpmSelfTest *test)
 {
-	test->type = "GpmArrayFloat    ";
 	GArray *array;
 	GArray *kernel;
 	GArray *result;
@@ -37,6 +36,10 @@ gpm_st_array_float (GpmSelfTest *test)
 	gfloat sigma;
 	guint size;
 
+	if (gpm_st_start (test, "GpmArrayFloat", CLASS_AUTO) == FALSE) {
+		return;
+	}
+
 	/************************************************************/
 	gpm_st_title (test, "make sure we get a non null array");
 	array = gpm_array_float_new (10);
@@ -46,6 +49,7 @@ gpm_st_array_float (GpmSelfTest *test)
 		gpm_st_failed (test, "could not get GArray");
 	}
 	gpm_array_float_print (array);
+	gpm_array_float_free (array);
 
 	/************************************************************/
 	gpm_st_title (test, "make sure we get the correct length array");
@@ -333,5 +337,7 @@ gpm_st_array_float (GpmSelfTest *test)
 	gpm_array_float_free (result);
 	gpm_array_float_free (array);
 	gpm_array_float_free (kernel);
+
+	gpm_st_end (test);
 }
 
